Installation
============

Invenio-Circulation is on PyPI so all you need is:

.. code-block:: console

   $ pip install invenio-circulation

Development installation:

.. code-block:: console

   $ pip install -r requirements-devel.txt
   $ pip install -e .[all,elasticsearch6,postgresql]
